@@ -7,7 +7,7 @@ package Mysql::Statement;
 use strict;
 use vars qw($OPTIMIZE $VERSION $AUTOLOAD);
 
-$VERSION = '1.19_21';
+$VERSION = '1.19_22';
 
 $OPTIMIZE = 0; # controls, which optimization we default to
 
@@ -114,7 +114,7 @@ sub as_string {
 	return '';
     }
     for (0..$sth->numfields-1) {
-	$l=length($sth->name->[$_]);
+	$l=CORE::length($sth->name->[$_]);
 	if ($l < $sth->maxlength->[$_]) {
 	    $l= $sth->maxlength->[$_];
 	}
