@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.01_21';
+$VERSION = '2.01_22';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -803,74 +803,37 @@ be.)
 =back
 
 
+=head1 MULTITHREADING
+
+The multithreading capabilities of the Msql-Mysql-modules depend completely
+on the underlying C libraries: The modules are working with handle data
+only, no global variables are accessed or (to the best of my knowledge)
+thread unsafe functions are called. Thus DBD::mSQL and DBD::mysql are
+completely thread safe, if the C libraries thread safe and you don't
+share handles among threads.
+
+The obvious questions is: Are the C libraries thread safe? In the case of
+mSQL the answer is definitely "no". The C library has a concept of one
+single active connection at a time and that is not what threads like.
+
+In the case of MySQL the answer is "mostly" and, in theory, you should
+be able to get a "yes", if the C library is compiled for being thread
+safe (By default it isn't.) by passing the option -with-thread-safe-client
+to configure. See the section on I<How to make a threadsafe client> in
+the manual.
+
+
 =head1 BUGS
 
 The I<port> part of the first argument to the connect call is
 implemented in an unsafe way when using mSQL. In fact it is just
-stting the environment variable MSQL_TCP_PORT during the connect
+setting the environment variable MSQL_TCP_PORT during the connect
 call. If another connect call uses another port and the handles
 are used simultaneously, they will interfere. I doubt that this
 will ever change.
 
-Please speak up now (June 1997) if you encounter additional bugs. I'm
-still learning about the DBI API and can neither judge the quality of
-the code presented here nor the DBI compliancy. But I'm intending to
-resolve things quickly as I'd really like to get rid of the multitude
-of implementations ASAP.
 
-When running "make test", you will notice that some test scripts fail.
-This is due to bugs in the respective databases, not in the DBI drivers:
-
-=over 4
-
-=item Nulls
-
-mSQL seems to have problems with NULL's: The following fails with
-mSQL 2.0.1 running on a Linux 2.0.30 machine:
-
-    [joe@laptop Msql-modules-1.18]$ msql test
-    Welcome to the miniSQL monitor.  Type \h for help.
-    mSQL > CREATE TABLE foo (id INTEGER, name CHAR(6))\g
-    Query OK.  1 row(s) modified or retrieved.
-    mSQL > INSERT INTO foo VALUES (NULL, 'joe')\g
-    Query OK.  1 row(s) modified or retrieved.
-    mSQL > SELECT * FROM foo WHERE id = NULL\g
-    Query OK.  0 row(s) modified or retrieved.
-    +----------+------+
-    | id       | name |
-    +----------+------+
-    +----------+------+
-    mSQL > 
-
-=item Blanks
-
-mysql has problems with Blanks on the right side of string fields: They
-get chopped of. (Tested with mysql 3.20.25 on a Linux 2.0.30 machine.)
-
-    [joe@laptop Msql-modules-1.18]$ mysql test
-    Welcome to the mysql monitor.  Commands ends with ; or \g.
-    Type 'help' for help.
-    mysql> CREATE TABLE foo (id INTEGER, bar CHAR(8));
-    Query OK, 0 rows affected (0.10 sec)
-    mysql> INSERT INTO foo VALUES (1, ' a b c ');
-    Query OK, 1 rows affected (0.00 sec)
-    mysql> SELECT * FROM foo;
-    1 rows in set (0.19 sec)
-    +------+--------+
-    | id   | bar    |
-    +------+--------+
-    |    1 |  a b c |
-    +------+--------+
-    mysql> quit;
-    [joe@laptop Msql-modules-1.18]$ mysqldump test foo
-
-    [deleted]
-
-    INSERT INTO foo VALUES (1,' a b c');
-
-=back
-
-=head1 AUTHOR
+=head1 AUTHORS
 
 B<DBD::mSQL> has been primarily written by Alligator Descartes
 (I<descarte@hermetica.com>), who has been aided and abetted by Gary
