@@ -331,6 +331,10 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
 
 int dbd_db_login(SV* dbh, imp_dbh_t* imp_dbh, char* dbname, char* user,
 		 char* password) {
+#ifdef dTHR
+    dTHR;
+#endif
+
     if (dbis->debug >= 2)
         fprintf(DBILOGFP, "imp_dbh->connect: dsn = %s, uid = %s, pwd = %s\n",
 	       dbname ? dbname : "NULL",
@@ -403,6 +407,10 @@ int dbd_db_rollback(SV* dbh, imp_dbh_t* imp_dbh) {
  **************************************************************************/
 
 int dbd_db_disconnect(SV* dbh, imp_dbh_t* imp_dbh) {
+#ifdef dTHR
+    dTHR;
+#endif
+
     /* We assume that disconnect will always work       */
     /* since most errors imply already disconnected.    */
     DBIc_ACTIVE_off(imp_dbh);
@@ -434,6 +442,7 @@ int dbd_discon_all (SV *drh, imp_drh_t *imp_drh) {
 #if defined(dTHR)
     dTHR;
 #endif
+
     /* The disconnect_all concept is flawed and needs more work */
     if (!dirty && !SvTRUE(perl_get_sv("DBI::PERL_ENDING",0))) {
 	sv_setiv(DBIc_ERR(imp_drh), (IV)1);
@@ -847,6 +856,9 @@ int dbd_st_execute(SV* sth, imp_sth_t* imp_sth) {
     D_imp_dbh_from_sth;
     SV** statement;
     int i;
+#if defined (dTHR)
+    dTHR;
+#endif
 
     if (dbis->debug >= 2) {
         fprintf(DBILOGFP, "    -> dbd_st_execute for %08lx\n", (u_long) sth);
@@ -1023,6 +1035,10 @@ AV* dbd_st_fetch(SV* sth, imp_sth_t* imp_sth) {
  **************************************************************************/
 
 int dbd_st_finish(SV* sth, imp_sth_t* imp_sth) {
+#if defined (dTHR)
+    dTHR;
+#endif
+
     /* Cancel further fetches from this cursor.                 */
     /* We don't close the cursor till DESTROY.                  */
     /* The application may re execute it.                       */
